@@ -136,7 +136,7 @@ def make_dataset(
     logging.info("Loading anndata to memory")
     adata = pp.read_h5ad(h5ad_input, raw=raw)
     background_file = background
-    background = pd.read_csv(background, index_col=False)
+    background = pd.read_csv(background, index_col=False, comment="#")
 
     adata = pp.assign_cell_type(adata, background)
 
